Message Carbons — Poezio 0.9-dev documentation

# Message Carbons

Starting from poezio 0.8, poezo now supports message carbons.

Message carbons are useful to duplicate chat messages between several connected devices, so that when you switch from one to another, you don’t lose any message you sent or received.

To enable it, you only have to set the enable_carbons option to `true`.

Note

This feature only duplicates chat messages (direct conversations between two JIDs), not groupchat messages or private conversations in groupchats.